package com.xinelu.manage.service.patientvisitoperation;

import java.util.List;

import com.xinelu.manage.domain.patientvisitoperation.PatientVisitOperation;

/**
 * 患者就诊手术记录信息Service接口
 *
 * @author xinelu
 * @date 2024-02-26
 */
public interface IPatientVisitOperationService {
    /**
     * 查询患者就诊手术记录信息
     *
     * @param id 患者就诊手术记录信息主键
     * @return 患者就诊手术记录信息
     */
    public PatientVisitOperation selectPatientVisitOperationById(Long id);

    /**
     * 查询患者就诊手术记录信息列表
     *
     * @param patientVisitOperation 患者就诊手术记录信息
     * @return 患者就诊手术记录信息集合
     */
    public List<PatientVisitOperation> selectPatientVisitOperationList(PatientVisitOperation patientVisitOperation);

	/**
	 * 根据患者就诊记录查询患者就诊手术记录信息
	 *
	 * @param patientVisitRecordId 患者就诊记录信息主键
	 * @return 患者就诊手术记录信息
	 */
	PatientVisitOperation getByVisitRecord(Long patientVisitRecordId);

    /**
     * 新增患者就诊手术记录信息
     *
     * @param patientVisitOperation 患者就诊手术记录信息
     * @return 结果
     */
    public int insertPatientVisitOperation(PatientVisitOperation patientVisitOperation);

    /**
     * 修改患者就诊手术记录信息
     *
     * @param patientVisitOperation 患者就诊手术记录信息
     * @return 结果
     */
    public int updatePatientVisitOperation(PatientVisitOperation patientVisitOperation);

    /**
     * 批量删除患者就诊手术记录信息
     *
     * @param ids 需要删除的患者就诊手术记录信息主键集合
     * @return 结果
     */
    public int deletePatientVisitOperationByIds(Long[] ids);

    /**
     * 删除患者就诊手术记录信息信息
     *
     * @param id 患者就诊手术记录信息主键
     * @return 结果
     */
    public int deletePatientVisitOperationById(Long id);
}
